TestAsyncExecutorTaskWaiter

Struct TestAsyncExecutorTaskWaiter 

pub struct TestAsyncExecutorTaskWaiter<T: Send> { /* private fields */ }
Waiter to be returned for top level Futures via TestAsyncExecutor::spawn().

A TestAsyncExecutorTaskWaiter provides a means to obtain the Output of the associated enqueued Future when Ready.

Note that a TestAsyncExecutorTaskWaiter implements Future itself, so it can get enqueued to the TestAsyncExecutor or polled from another owning Future.

Implementations

Source

impl<T: Send> TestAsyncExecutorTaskWaiter<T>

pub fn take(self) -> Option<T>

Take the associated enqueued Future’s Output if Ready.

Returns None if the (future::Future::Output) is not Ready yet or the result has already been taken, including through Self::poll().